@@ -4,11 +4,17 @@ module.exports = function(hg, done) {
 	var getSql = function(id) {
 		var sql = 'SELECT \'blogs\' AS domain, e.id, e.title, e.content AS body, e.created_by AS contributor_ids, state, ' +
 			'CASE WHEN state = 1 THEN 0 WHEN state = 2 THEN 2 ELSE NULL END AS access, ' +
-			'\'blogs\' AS standalone_domain, e.id AS \'standalone_id\', ' +
-			'CAST(CONCAT(\'/members/\', e.created_by, \'/blog/\', YEAR(e.publish_up), \'/\', LPAD(MONTH(e.publish_up), 2, \'0\'), \'/\', alias)  AS CHAR) AS link, ' +
+			'\'blogs\' AS standalone_domain, e.id AS \'standalone_id\', scope, ' +
+			'CAST(CONCAT(' +
+				'CASE WHEN scope = \'group\' ' +
+				'THEN CONCAT(\'/groups/\', xg.cn) ' +
+				'ELSE CONCAT(\'/members/\', e.scope_id) END, ' +
+				'\'/blog/\', YEAR(e.publish_up), \'/\', LPAD(MONTH(e.publish_up), 2, \'0\'), \'/\', alias' +
+			') AS CHAR) AS link, xg.gidNumber AS group_ids, ' +
 			'(SELECT group_concat(DISTINCT jto.tagid separator \'\\n\') FROM jos_tags_object jto INNER JOIN jos_tags jt ON jt.id = jto.tagid WHERE jto.tbl = \'blog\' AND jto.objectid = e.id) AS tag_ids ' +
 			'FROM jos_blog_entries e ' +
 			'INNER JOIN jos_xprofiles xp ON xp.uidNumber = e.created_by AND xp.public ' +
+			'LEFT JOIN jos_xgroups xg ON e.scope = \'group\' && xg.gidNumber = e.scope_id ' +
 			'WHERE publish_up <= UTC_TIMESTAMP() AND state != -1';
 
 		return id ? sql + ' AND e.id = ' + (id * 1) : sql;
