@@ -1,8 +1,5 @@
 module.exports = function(hg, done) {
 	hg.event.observe('onUsersLoaded', function(client) {
-done(); 
-hg.event.emit('onCitationsLoaded', [client]);
-return;
 		var cols = null;
 		var getSql = function(id) {
 			var sql = 'SELECT ' +
@@ -35,9 +32,6 @@ return;
 		};
 		var idx = 0;
 		var add = function(res) {
-			if (++idx % 100 == 0) {
-				console.log(idx);
-			}
 			res.link = '/citations/view/' + res.id + (res.link ? "\n" + res.link : '');
 			hg.addWithCommonConnections(res);
 			hg.add({'domain': 'aliases', 'title': res.authors, 'id': 'authortext:' + res.authors});
