@@ -2,9 +2,9 @@ module.exports = function(hg, done) {
 	var getSql = function(id) {
 		var sql = 'SELECT \'content pages\' AS domain, c.id, c.title, CAST(concat(coalesce(c.introtext, \'\'), coalesce(c.`fulltext`, \'\')) AS CHAR) AS body, ' +
 			'CAST(CASE ' +
-				'WHEN ca.alias != \'\' OR c.alias != \'\' THEN ' +
+				'WHEN ca.path != \'\' OR c.alias != \'\' THEN ' +
 					' concat(' +
-						'CASE WHEN ca.alias != \'\' THEN concat(\'/\', ca.alias) ELSE \'\' END, ' +
+						'CASE WHEN ca.path != \'\' THEN concat(\'/\', ca.path) ELSE \'\' END, ' +
 						'CASE WHEN c.alias != \'\' THEN concat(\'/\', c.alias) ELSE \'\' END ' +
 					') ' +
 				'ELSE concat(\'/content/article/\', c.id) ' +
