@@ -2,7 +2,7 @@ module.exports = function(hg, done) {
 	hg.event.observe('onContentLoaded', function(client) {
 		var getSql = function(id) {
 			var sql = 'SELECT \'knowledge base articles\' AS domain, f.title, created AS date, f.id, c.title AS logical_type, s.title AS type, ' +
-				'CAST(concat(coalesce(f.params, \'\'), coalesce(f.`fulltxt`, \'\')) AS CHAR) AS body, ' +
+				'coalesce(f.`fulltxt`, \'\') AS body, ' +
 				'CAST(concat(\'/kb/\', coalesce(concat(s.alias, \'/\'), \'\'), f.alias) AS CHAR) AS link ' +
 				'FROM jos_faq f ' +
 				'LEFT JOIN jos_faq_categories s ON s.id = f.section ' +
