@@ -13,7 +13,7 @@ module.exports = function(hg, done) {
 		var add = function(res) {
 			client.query(
 				'SELECT \'answers\' AS domain, r.id, r.question_id AS standalone_id, \'questions\' AS standalone_domain, r.answer AS body, r.created AS date, ' +
-				'CASE WHEN r.anonymous THEN NULL ELSE (SELECT id FROM jos_users WHERE username = r.created_by) END AS contributor_ids ' +
+				'CASE WHEN r.anonymous THEN NULL ELSE (SELECT id FROM jos_users WHERE username = r.created_by LIMIT 1) END AS contributor_ids ' +
 				'FROM jos_answers_responses r ' +
 				'WHERE r.question_id = ' + res.id,
 				function(err2, results2) {
