@@ -91,7 +91,7 @@ module.exports = function(hg, done) {
 		};
 		
 		hg.event.observe('onInsertTagsObject', function(client, row) {
-			client.query('SELECT t.tagid, jto.tbl, jto.objectid FROM jos_tags t INNER JOIN jos_tags_object jto ON jto.tagid = t.id AND jto.id = ' + (1*row.id), function(err, results) {
+			client.query('SELECT t.id, jto.tbl, jto.objectid FROM jos_tags t INNER JOIN jos_tags_object jto ON jto.tagid = t.id AND jto.id = ' + (1*row.id), function(err, results) {
 				if (err) {
 					throw err;
 				}
