@@ -22,11 +22,8 @@ module.exports = function(hg, done) {
 			client.query(sql, function(err, results) {                                                                                                                                                                                                                                   
 				if (err) {
 					if (err.message.indexOf('ER_BAD_FIELD_ERROR') == -1) {
-						console.log(err.message);
 						throw err;
 					}
-					console.log('skipping: ');
-					console.log(err.message);
 					return;
 				}
 				hg.log(results.length + ' wiki/topic pages');
