@@ -1,4 +1,5 @@
 module.exports = function(hg) {
+	hg.log('reloadd');
 	hg.views.filterVisible = function(item, args) {
 		if (args.super) {
 			return true;
@@ -46,7 +47,6 @@ module.exports = function(hg) {
 			'discussions'  : 'forum',
 			'blogs'        : 'blog',
 			'wishes'       : 'wishlist',
-			'resources'    : 'resources',
 			'events'       : 'calendar',
 			'announcements': 'announcements',
 			'collections'  : 'collections'
@@ -59,9 +59,6 @@ module.exports = function(hg) {
 					hg.log('warning: no group permissions set for ' + gid);
 					return false;
 				}
-				if (hg.groupPerms[gid].privacy == 1 && !args.groupMap[gid]) {
-					return false;
-				}
 				var param = groupParamDomainMap[item.domain];
 				if (param) {
 					var perms = hg.groupPerms[gid].params[param];
@@ -812,6 +809,10 @@ module.exports = function(hg) {
 					// nerf for being a non-contributor
 					return item.weight/2;
 				}
+
+				if (item.domain == 'resources' && item.type == 'Tools') {
+					item.weight *= 6;
+				}
 				return item.weight;
 			});
 		if (!anyTimes) {
